@@ -16,7 +16,7 @@ from datetime import datetime
 
 
 # Current version number
-__version__ = "0.3.5"
+__version__ = "0.3.6"
 
 
 # Some constants
@@ -501,7 +501,7 @@ def create_version(version: int, settings: configparser.SectionProxy) -> t.Set[i
                                 if transform:
                                     line = transform(line)
                                 outf.write(line)
-                                is_empty = is_empty or len(line.strip()) > 0
+                                is_empty = is_empty and len(line.strip()) > 0
                             line = inf.readline()
                 if is_empty and not keep_empty_files:
                     os.remove(fulloutpath)
